/*
 * Copyright (c) 2023, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "ti/driverlib/m0p/dl_core.h"
#include "ti_msp_dl_config.h"
#include <string.h>

// prototypes
void StartSerialTX(char *str);

// Serial stuff
volatile uint8_t RXdata = 0;

volatile int TXChar = -1;
char TXData[64];

int main(void) {
  char echo_str[2] = "e";

  SYSCFG_DL_init();

  // Kick off the interrupts
  NVIC_ClearPendingIRQ(UART_0_INST_INT_IRQN);
  NVIC_EnableIRQ(UART_0_INST_INT_IRQN);

  StartSerialTX("Hello, World!\n\r");

  while (1) {

    if (RXdata != 0) {
      echo_str[0] = RXdata;
      StartSerialTX(echo_str);
      RXdata = 0;
    }

    delay_cycles(1000);
  }
}

void StartSerialTX(char *str) {

  while (TXChar != -1) {
    // wait for previous tx to finish
    delay_cycles(10000);
  }

  strcpy(TXData, str);

  TXChar = 0;

  // Kick it in the pants to get it going
  DL_UART_Main_transmitData(UART_0_INST, TXData[TXChar++]);
}

void UART_0_INST_IRQHandler(void) {
  switch (DL_UART_Main_getPendingInterrupt(UART_0_INST)) {

  case DL_UART_MAIN_IIDX_RX:
    RXdata = DL_UART_Main_receiveData(UART_0_INST);
    break;

  case DL_UART_MAIN_IIDX_TX:
    if (TXData[TXChar] != '\0') {
      DL_UART_Main_transmitData(UART_0_INST, TXData[TXChar++]);
    } else {
      TXChar = -1;
    }

    break;

  default:
    break;
  }
}
